@@ -125,10 +125,11 @@ namespace Extension
 	DECL_SHARED_PTR(RegexParametresElement);
 	struct RegexParametresElement : public RegexParametres, public std::enable_shared_from_this<RegexParametresElement>
 	{
-		RegexParametresElement()
-		:_modifiable(false) {}
+		explicit RegexParametresElement(const bool modifiable = false)
+		:_modifiable(modifiable) {}
 		virtual ~RegexParametresElement() {}
-		virtual RegexParametresElementSP joker() const = 0;
+		virtual const RegexParametresElementSP& joker() const = 0;
+		virtual RegexParametresElementSP version_non_modifiable() const = 0;
 		virtual bool operator<(const RegexParametresElement& element) const = 0;
 		virtual bool operator==(const RegexParametresElement& element) const = 0;
 		virtual RegexParametresElementSP copie() const = 0;
@@ -144,9 +145,14 @@ namespace Extension
 		{
 			os << ".";
 		}
-		virtual RegexParametresElementSP joker() const override
+		virtual const RegexParametresElementSP& joker() const override
 		{
-			return RegexParametresElementSP();
+			static auto joker = RegexParametresElementSP();
+			return joker;
+		}
+		virtual RegexParametresElementSP version_non_modifiable() const override
+		{
+			return std::make_shared<RegexParametresJokerTotal>();
 		}
 		virtual operator AutomateNonDeterministeSP () const override;
 		virtual RegexParametresElementSP copie() const override
@@ -213,6 +219,8 @@ namespace Extension
 */
 	struct RegexParametresJokerPartielValeur : public RegexParametresElement
 	{
+		explicit RegexParametresJokerPartielValeur(const bool modifiable = false)
+		:RegexParametresElement(modifiable) {}
 		virtual ~RegexParametresJokerPartielValeur() {}
 		virtual void format(std::ostream& os) const override
 		{
@@ -222,9 +230,14 @@ namespace Extension
 			}
 			os << "VALUE";
 		}
-		virtual RegexParametresElementSP joker() const override
+		virtual const RegexParametresElementSP& joker() const override
 		{
-			return std::make_shared<RegexParametresJokerTotal>();
+			static RegexParametresElementSP joker = std::make_shared<RegexParametresJokerTotal>();
+			return joker;
+		}
+		virtual RegexParametresElementSP version_non_modifiable() const override
+		{
+			return std::make_shared<RegexParametresJokerPartielValeur>();
 		}
 		virtual operator AutomateNonDeterministeSP () const override;
 		virtual RegexParametresElementSP copie() const override
@@ -269,11 +282,15 @@ namespace Extension
 			}
 			os << _type;
 		}
-		virtual RegexParametresElementSP joker() const override
+		virtual const RegexParametresElementSP& joker() const override
 		{
-			auto j = std::make_shared<RegexParametresJokerPartielValeur>();
-			j->_modifiable=_modifiable;
-			return j;
+			static RegexParametresElementSP joker = std::make_shared<RegexParametresJokerPartielValeur>();
+			static RegexParametresElementSP joker_modifiable = std::make_shared<RegexParametresJokerPartielValeur>(true);
+			return _modifiable?joker_modifiable:joker;
+		}
+		virtual RegexParametresElementSP version_non_modifiable() const override
+		{
+			return std::make_shared<RegexParametresValeur>(_type);
 		}
 		virtual operator AutomateNonDeterministeSP () const override;
 		virtual RegexParametresElementSP copie() const override
@@ -318,9 +335,14 @@ namespace Extension
 		{
 			os << "MARKER";
 		}
-		virtual RegexParametresElementSP joker() const override
+		virtual const RegexParametresElementSP& joker() const override
 		{
-			return std::make_shared<RegexParametresJokerTotal>();
+			static RegexParametresElementSP joker = std::make_shared<RegexParametresJokerTotal>();
+			return joker;
+		}
+		virtual RegexParametresElementSP version_non_modifiable() const override
+		{
+			return std::make_shared<RegexParametresJokerPartielMarqueur>();
 		}
 		virtual operator AutomateNonDeterministeSP () const override;
 		virtual RegexParametresElementSP copie() const override
@@ -354,9 +376,14 @@ namespace Extension
 		{
 			os << _marqueur;
 		}
-		virtual RegexParametresElementSP joker() const override
+		virtual const RegexParametresElementSP& joker() const override
 		{
-			return std::make_shared<RegexParametresJokerPartielMarqueur>();
+			static RegexParametresElementSP joker = std::make_shared<RegexParametresJokerPartielMarqueur>();
+			return joker;
+		}
+		virtual RegexParametresElementSP version_non_modifiable() const override
+		{
+			return std::make_shared<RegexParametresMarqueur>(_marqueur);
 		}
 		virtual operator AutomateNonDeterministeSP () const override;
 		virtual RegexParametresElementSP copie() const override
@@ -393,9 +420,14 @@ namespace Extension
 		{
 			os << "KEYWORD";
 		}
-		virtual RegexParametresElementSP joker() const override
+		virtual const RegexParametresElementSP& joker() const override
 		{
-			return std::make_shared<RegexParametresJokerTotal>();
+			static RegexParametresElementSP joker = std::make_shared<RegexParametresJokerTotal>();
+			return joker;
+		}
+		virtual RegexParametresElementSP version_non_modifiable() const override
+		{
+			return std::make_shared<RegexParametresJokerPartielMotClef>();
 		}
 		virtual operator AutomateNonDeterministeSP () const override;
 		virtual RegexParametresElementSP copie() const override
@@ -427,9 +459,14 @@ namespace Extension
 		{
 			os << "'" << _mot_clef << "'";
 		}
-		virtual RegexParametresElementSP joker() const override
+		virtual const RegexParametresElementSP& joker() const override
 		{
-			return std::make_shared<RegexParametresJokerPartielMotClef>();
+			static RegexParametresElementSP joker = std::make_shared<RegexParametresJokerPartielMotClef>(); 
+			return joker;
+		}
+		virtual RegexParametresElementSP version_non_modifiable() const override
+		{
+			return std::make_shared<RegexParametresMotClef>(_mot_clef);
 		}
 		virtual operator AutomateNonDeterministeSP () const override;
 		virtual RegexParametresElementSP copie() const override
@@ -461,6 +498,8 @@ namespace Extension
 
 	struct RegexParametresJokerPartielStructure : public RegexParametresElement
 	{
+		explicit RegexParametresJokerPartielStructure(const bool modifiable = false)
+		:RegexParametresElement(modifiable) {}
 		virtual ~RegexParametresJokerPartielStructure() {}
 		virtual void format(std::ostream& os) const override
 		{
@@ -470,9 +509,14 @@ namespace Extension
 			}
 			os << "STRUCT";
 		}
-		virtual RegexParametresElementSP joker() const override
+		virtual const RegexParametresElementSP& joker() const override
 		{
-			return std::make_shared<RegexParametresJokerTotal>();
+			static RegexParametresElementSP joker = std::make_shared<RegexParametresJokerTotal>();
+			return joker;
+		}
+		virtual RegexParametresElementSP version_non_modifiable() const override
+		{
+			return std::make_shared<RegexParametresJokerPartielStructure>();
 		}
 		virtual operator AutomateNonDeterministeSP () const override;
 		virtual RegexParametresElementSP copie() const override
@@ -503,38 +547,6 @@ namespace Extension
 		virtual char type() const { return 7; }
 	};
 
-	struct RegexParametresJokerPartielVariable : public RegexParametresElement
-	{
-		virtual ~RegexParametresJokerPartielVariable() {}
-		virtual void format(std::ostream& os) const override
-		{
-			os << "VARIABLE";
-		}
-		virtual RegexParametresElementSP joker() const override
-		{
-			return std::make_shared<RegexParametresJokerTotal>();
-		}
-		virtual operator AutomateNonDeterministeSP () const override;
-		virtual RegexParametresElementSP copie() const override
-		{
-			auto c = std::make_shared<RegexParametresJokerPartielVariable>();
-			c->_modifiable = _modifiable;
-			return c;
-		}
-		virtual bool operator<(const RegexParametresElement& element) const override
-		{
-			auto t = type();
-			auto tt = element.type();
-			if(t!=tt) { return t<tt; }
-			return false;
-		}
-		virtual bool operator==(const RegexParametresElement& element) const override
-		{
-			return (type()==element.type());
-		}
-		virtual char type() const { return 8; }
-	};
-
 	DECL_SHARED_PTR(RegexParametresStructure);
 	struct RegexParametresStructure : public RegexParametresElement
 	{
@@ -549,11 +561,15 @@ namespace Extension
 			}
 			os << "$" << _type;
 		}
-		virtual RegexParametresElementSP joker() const override
+		virtual const RegexParametresElementSP& joker() const override
 		{
-			auto j = std::make_shared<RegexParametresJokerPartielStructure>();
-			j->_modifiable=_modifiable;
-			return j;
+			static RegexParametresElementSP joker = std::make_shared<RegexParametresJokerPartielStructure>();
+			static RegexParametresElementSP joker_modifiable = std::make_shared<RegexParametresJokerPartielStructure>(true);
+			return _modifiable?joker_modifiable:joker;
+		}
+		virtual RegexParametresElementSP version_non_modifiable() const override
+		{
+			return std::make_shared<RegexParametresStructure>(_type);
 		}
 		virtual operator AutomateNonDeterministeSP () const override;
 		virtual RegexParametresElementSP copie() const override
@@ -591,6 +607,43 @@ namespace Extension
 		SVM_Memoire::Type _type;
 	};
 
+	struct RegexParametresJokerPartielVariable : public RegexParametresElement
+	{
+		virtual ~RegexParametresJokerPartielVariable() {}
+		virtual void format(std::ostream& os) const override
+		{
+			os << "VARIABLE";
+		}
+		virtual const RegexParametresElementSP& joker() const override
+		{
+			static RegexParametresElementSP joker = std::make_shared<RegexParametresJokerTotal>();
+			return joker;
+		}
+		virtual RegexParametresElementSP version_non_modifiable() const override
+		{
+			return std::make_shared<RegexParametresJokerPartielVariable>();
+		}
+		virtual operator AutomateNonDeterministeSP () const override;
+		virtual RegexParametresElementSP copie() const override
+		{
+			auto c = std::make_shared<RegexParametresJokerPartielVariable>();
+			c->_modifiable = _modifiable;
+			return c;
+		}
+		virtual bool operator<(const RegexParametresElement& element) const override
+		{
+			auto t = type();
+			auto tt = element.type();
+			if(t!=tt) { return t<tt; }
+			return false;
+		}
+		virtual bool operator==(const RegexParametresElement& element) const override
+		{
+			return (type()==element.type());
+		}
+		virtual char type() const { return 8; }
+	};
+
 	struct RegexParametresPasDeParametres : public RegexParametresElement
 	{
 		// Cette structure sert juste a indiquer qu'aucun parametre est
@@ -603,7 +656,8 @@ namespace Extension
 		{
 			os << "no parameter";
 		}
-		virtual RegexParametresElementSP joker() const override { throw; }
+		virtual const RegexParametresElementSP& joker() const override { throw; }
+		virtual RegexParametresElementSP version_non_modifiable() const override { throw; }
 		virtual operator AutomateNonDeterministeSP () const override { throw; }
 		virtual RegexParametresElementSP copie() const override { throw; }
 		virtual bool operator<(const RegexParametresElement& element) const override { throw; }
